package cz.moneta.test.regression.backoffice.callcenter.jenkinstests.ccretail.cczakladadc;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.util.credentials.Keys;
import cz.moneta.test.dsl.util.task.ufo.operations.OperationsTasks;
import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.harness.support.auth.Credentials;
import cz.moneta.test.harness.support.auth.Key;
import org.junit.jupiter.api.BeforeAll;

import static cz.moneta.test.harness.annotations.Environment.PPE;
import static cz.moneta.test.harness.annotations.Environment.TST1;

@TestScenario(name = "Internet bank active operations")
public class InternetBankActiveOperations {
    private OperationsTasks operationsTasks;
    private String rcOfExistingClient;

    @BeforeAll
    public void setupInfo(Harness harness) {
        operationsTasks = harness.tasks().ufo().operations();
        rcOfExistingClient = harness.getSystemOrConfigValue("cc.internetBanka.rc");
    }

    @TestCase(name = "Internet bank active operations - natural person", environments = {PPE, TST1})
    @JiraTestCase(id = "CC-T2110")
    public void ibActiveOperationsNaturalPerson(Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {

        harness.withUfo()
                .openLoginPage()
                .then(operationsTasks.login().withCredentials(credentials))
                .fillSearchInput(rcOfExistingClient)
                .clickSearchClient()
                .onClientDetailsPage()
                .clickIB()
                .clickDetailAdcProduct()
                .clickDetailEdisponent()
                .clickSendLoginPasswordSms()
                .checkIfStatusBarIsOverwritten(" Zaslání přihlašovacího hesla proběhlo v pořádku")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("ADC Helpdesk - Internet Banka - Přihlašování do IB - Nelze se přihlásit - Zaslání nového hesla Majiteli")
                .clickSendIdForIbSms()
                .checkIfStatusBarIsOverwritten(" Odeslání SMS s ID proběhlo v pořádku")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("UFO - Internet Banka - Zaslání ID pro IB aktivní - SMS")
                .scrollOnSmsPhishingButton()
                .clickPhisingSms()
                .checkIfStatusBarIsOverwritten(" Odeslání SMS (PHISHING) proběhlo v pořádku.")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("Call centrum Banka - Odeslání SMS - Podezření na Phishing Internet Banky")
                .scrollOnAllBlocationButton()
                .clickBlockationAllProfilesButton()
                .checkIfStatusBarIsOverwritten(" Blokace všech profilů proběhla v pořádku")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("ADC Helpdesk - Internet Banka - Blokace celého profilu - Majitel")
                .clickDetailOfClientButton()
                .checkInternetBankDispo("Internet Banka heslo/MK - Dispomodel (Blokovaný)")
                .checkSmartBankDispo("Smart Banka - Dispomodel (Blokovaný)")
                .clickIB()
                .clickDetailAdcProduct()
                .clickDetailEdisponent()
                .clickUnblocationAllProfiles()
                .checkIfStatusBarIsOverwritten(" Odblokace všech profilů proběhla v pořádku")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("ADC Helpdesk - Internet Banka - Odblokace celého profilu - Majitel")
                .clickDetailOfClientButton()
                .checkInternetBankDispo("Internet Banka heslo/MK - Dispomodel (Aktivní)")
                .checkSmartBankDispo("Smart Banka - Dispomodel (Aktivní)")
                .clickIB()
                .clickDetailAdcProduct()
                .clickDetailEdisponent()
                .clickBloationOfIbCanal()
                .checkIfStatusBarIsOverwritten(" Blokace kanálu proběhla v pořádku")
                .checkStateOfIbCanal("Blokovaný")
                .checkCanalInRow("IB")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("ADC Helpdesk - Internet Banka - Blokace IB")
                .clickDetailOfClientButton()
                .checkInternetBankDispo("Internet Banka heslo/MK - Dispomodel (Blokovaný)")
                .clickIB()
                .clickDetailAdcProduct()
                .clickDetailEdisponent()
                .clickCancelBlocationOfIBCanal()
                .checkStateOfIbCanal("Aktivní")
                .checkIfStatusBarIsOverwritten(" Odblokace kanálu proběhla v pořádku")
                .clickRequirement()
                .clickRefreshRequirement()
                .checkRequirementDescription("ADC Helpdesk - Internet Banka - Odblokace kanálu")
                .clickDetailOfClientButton()
                .checkInternetBankDispo("Internet Banka heslo/MK - Dispomodel (Aktivní)");
    }
}